<h1 align="center">
  <a href="https://pypi.org/project/filescope/"><img src="https://i.imgur.com/qgT6wPW.png" alt="filescope logo"></a>
</h1>

<div align="center">
  <strong>:open_file_folder: Gerenciamento de arquivos em diretórios locais :open_file_folder:</strong>
</div>
<br/>

<div align="center">  
  
  ![Release](https://img.shields.io/badge/release-ok-brightgreen)
  [![PyPI](https://img.shields.io/pypi/v/filescope?color=blueviolet)](https://pypi.org/project/filescope/)
  ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/filescope?color=green)
  ![PyPI - Status](https://img.shields.io/pypi/status/filescope)

</div>
<br/>

<div align="center">
  Work in progress!
</div>
<br/>
